--+--------------------------------------------------------------------------+
--| Copyright 1992 - 2002 Rational Software Corporation. All Rights Reserved.|
--| This software contains proprietary and confidential information of       |
--| Rational and its suppliers. Use, disclosure or reproduction is           |
--| prohibited without the prior express written consent of Rational.        |
--+--------------------------------------------------------------------------+
--
-- ///////////////////////////////////////////////////////////////////////// --

with System;
with Unix_Types;

package Thread_Unix_Variables is

    pragma Preelaborate (Thread_Unix_Variables);

    -- Using the interfaces provided in the Unix_Operations is preferred
    -- over this package.  This package provides host-specific definitions
    -- for applications that really need them.

    Argc : Integer;
    Argv : Unix_Types.Char_Ptr_Ptr;
    Envp : Unix_Types.Char_Ptr_Ptr;
    -- Copies of the main program arguments.

    Environ : Unix_Types.Char_Ptr_Ptr;
    -- Global environment pointer; initialized to Envp at process startup.

    function Get_Errno return Unix_Types.Int;
    procedure Set_Errno (Err : Unix_Types.Int);
    -- Global error indicator for system calls.

    function Errno return Unix_Types.Int renames Get_Errno;
    -- This provides backward compatibility for uses of Errno with
    -- runtimes based on POSIX threads.  This used to be an import
    -- of the C variable errno, but that is not provided by all
    -- OS implementations of threads, and is almost never the right
    -- thing to use in any case.
    -- Note that this only works if Errno is used as part of an expression
    -- to get the current value; it can't be used on the left hand side of
    -- an assignment statement.  Such uses must be replaced by calls to
    -- Set_Errno.

private

    pragma Import (C, Argc, Link_Name => "__argc_value");
    pragma Import (C, Argv, Link_Name => "__argv_value");
    pragma Import (C, Envp, External_Name => "environ");
    pragma Import (C, Environ);

    pragma Inline_Only (Get_Errno);
    pragma Inline_Only (Set_Errno);

end Thread_Unix_Variables;
